pynrc.simul.dms
===============

.. automodule:: pynrc.simul.dms

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
      :toctree:
   
      DMS_filename
      compute_local_roll
      create_DMS_HDUList
      create_group_entry
      dec_to_base36
      filename_visit_info
      jw_obs_id
      level1b_data_model
      populate_group_table
      save_level1b_fits
      update_dms_headers
      update_headers_pynrc_info
   
   

   
   
   

   
   
   



